gtk+ r20448 - in trunk: . gtk



Author: mitch
Date: Wed Jun 18 09:12:32 2008
New Revision: 20448
URL: http://svn.gnome.org/viewvc/gtk+?rev=20448&view=rev

Log:
2008-06-18  Michael Natterer  <mitch imendio com>

	* gtk/gtktypeutils.h: deprecate GtkDestroyNotify.

	* gtk/gtkactiongroup.[ch]
	* gtk/gtkcombobox.[ch]
	* gtk/gtkcontainer.[ch]
	* gtk/gtkliststore.[ch]
	* gtk/gtkmain.[ch]
	* gtk/gtkmenu.c
	* gtk/gtkstock.[ch]
	* gtk/gtktreedatalist.[ch]
	* gtk/gtktreemodelfilter.[ch]
	* gtk/gtktreemodelsort.[ch]
	* gtk/gtktreeprivate.h
	* gtk/gtktreeselection.[ch]
	* gtk/gtktreesortable.[ch]
	* gtk/gtktreestore.[ch]
	* gtk/gtktreeview.[ch]
	* gtk/gtktreeviewcolumn.[ch]: s/GtkDestroyNotify/GDestroyNotify/g.



Modified:
   trunk/ChangeLog
   trunk/gtk/gtkactiongroup.c
   trunk/gtk/gtkactiongroup.h
   trunk/gtk/gtkcombobox.c
   trunk/gtk/gtkcombobox.h
   trunk/gtk/gtkcontainer.c
   trunk/gtk/gtkcontainer.h
   trunk/gtk/gtkliststore.c
   trunk/gtk/gtkliststore.h
   trunk/gtk/gtkmain.c
   trunk/gtk/gtkmain.h
   trunk/gtk/gtkmenu.c
   trunk/gtk/gtkstock.c
   trunk/gtk/gtkstock.h
   trunk/gtk/gtktreedatalist.c
   trunk/gtk/gtktreedatalist.h
   trunk/gtk/gtktreemodelfilter.c
   trunk/gtk/gtktreemodelfilter.h
   trunk/gtk/gtktreemodelsort.c
   trunk/gtk/gtktreemodelsort.h
   trunk/gtk/gtktreeprivate.h
   trunk/gtk/gtktreeselection.c
   trunk/gtk/gtktreeselection.h
   trunk/gtk/gtktreesortable.c
   trunk/gtk/gtktreesortable.h
   trunk/gtk/gtktreestore.c
   trunk/gtk/gtktreestore.h
   trunk/gtk/gtktreeview.c
   trunk/gtk/gtktreeview.h
   trunk/gtk/gtktreeviewcolumn.c
   trunk/gtk/gtktreeviewcolumn.h
   trunk/gtk/gtktypeutils.h

Modified: trunk/gtk/gtkactiongroup.c
==============================================================================
--- trunk/gtk/gtkactiongroup.h	(original)
+++ trunk/gtk/gtkactiongroup.h	Wed Jun 18 09:12:32 2008
@@ -161,7 +161,7 @@
 void            gtk_action_group_set_translate_func      (GtkActionGroup             *action_group,
 							  GtkTranslateFunc            func,
 							  gpointer                    data,
-							  GtkDestroyNotify            notify);
+							  GDestroyNotify              notify);
 void            gtk_action_group_set_translation_domain  (GtkActionGroup             *action_group,
 							  const gchar                *domain);
 G_CONST_RETURN gchar *gtk_action_group_translate_string  (GtkActionGroup             *action_group,

Modified: trunk/gtk/gtkcombobox.c
==============================================================================
--- trunk/gtk/gtkcombobox.c	(original)
+++ trunk/gtk/gtkcombobox.c	Wed Jun 18 09:12:32 2008
@@ -123,7 +123,7 @@
 
   GtkTreeViewRowSeparatorFunc row_separator_func;
   gpointer                    row_separator_data;
-  GtkDestroyNotify            row_separator_destroy;
+  GDestroyNotify              row_separator_destroy;
 
   gchar *tearoff_title;
 };
@@ -5640,7 +5640,7 @@
 gtk_combo_box_set_row_separator_func (GtkComboBox                 *combo_box,
 				      GtkTreeViewRowSeparatorFunc  func,
 				      gpointer                     data,
-				      GtkDestroyNotify             destroy)
+				      GDestroyNotify               destroy)
 {
   g_return_if_fail (GTK_IS_COMBO_BOX (combo_box));
 

Modified: trunk/gtk/gtkcombobox.h
==============================================================================
--- trunk/gtk/gtkcombobox.h	(original)
+++ trunk/gtk/gtkcombobox.h	Wed Jun 18 09:12:32 2008
@@ -112,7 +112,7 @@
 void                        gtk_combo_box_set_row_separator_func (GtkComboBox                *combo_box,
 								  GtkTreeViewRowSeparatorFunc func,
 								  gpointer                    data,
-								  GtkDestroyNotify            destroy);
+								  GDestroyNotify              destroy);
 
 /* convenience -- text */
 GtkWidget    *gtk_combo_box_new_text         (void);

Modified: trunk/gtk/gtkcontainer.c
==============================================================================
--- trunk/gtk/gtkcontainer.c	(original)
+++ trunk/gtk/gtkcontainer.c	Wed Jun 18 09:12:32 2008
@@ -1512,7 +1512,7 @@
 			    GtkCallback         callback,
 			    GtkCallbackMarshal  marshal,
 			    gpointer            callback_data,
-			    GtkDestroyNotify    notify)
+			    GDestroyNotify      notify)
 {
   g_return_if_fail (GTK_IS_CONTAINER (container));
 

Modified: trunk/gtk/gtkcontainer.h
==============================================================================
--- trunk/gtk/gtkcontainer.h	(original)
+++ trunk/gtk/gtkcontainer.h	Wed Jun 18 09:12:32 2008
@@ -129,7 +129,7 @@
 				     GtkCallback         callback,
 				     GtkCallbackMarshal  marshal,
 				     gpointer            callback_data,
-				     GtkDestroyNotify    notify);
+				     GDestroyNotify      notify);
 #endif /*  GTK_DISABLE_DEPRECATED */
 GList*   gtk_container_get_children     (GtkContainer       *container);
 

Modified: trunk/gtk/gtkliststore.c
==============================================================================
--- trunk/gtk/gtkliststore.c	(original)
+++ trunk/gtk/gtkliststore.c	Wed Jun 18 09:12:32 2008
@@ -111,11 +111,11 @@
 						      gint                    sort_column_id,
 						      GtkTreeIterCompareFunc  func,
 						      gpointer                data,
-						      GtkDestroyNotify        destroy);
+						      GDestroyNotify          destroy);
 static void     gtk_list_store_set_default_sort_func (GtkTreeSortable        *sortable,
 						      GtkTreeIterCompareFunc  func,
 						      gpointer                data,
-						      GtkDestroyNotify        destroy);
+						      GDestroyNotify          destroy);
 static gboolean gtk_list_store_has_default_sort_func (GtkTreeSortable        *sortable);
 
 
@@ -392,7 +392,7 @@
   
   if (list_store->default_sort_destroy)
     {
-      GtkDestroyNotify d = list_store->default_sort_destroy;
+      GDestroyNotify d = list_store->default_sort_destroy;
 
       list_store->default_sort_destroy = NULL;
       d (list_store->default_sort_data);
@@ -1831,7 +1831,7 @@
 			      gint                    sort_column_id,
 			      GtkTreeIterCompareFunc  func,
 			      gpointer                data,
-			      GtkDestroyNotify        destroy)
+			      GDestroyNotify          destroy)
 {
   GtkListStore *list_store = (GtkListStore *) sortable;
 
@@ -1847,13 +1847,13 @@
 gtk_list_store_set_default_sort_func (GtkTreeSortable        *sortable,
 				      GtkTreeIterCompareFunc  func,
 				      gpointer                data,
-				      GtkDestroyNotify        destroy)
+				      GDestroyNotify          destroy)
 {
   GtkListStore *list_store = (GtkListStore *) sortable;
 
   if (list_store->default_sort_destroy)
     {
-      GtkDestroyNotify d = list_store->default_sort_destroy;
+      GDestroyNotify d = list_store->default_sort_destroy;
 
       list_store->default_sort_destroy = NULL;
       d (list_store->default_sort_data);

Modified: trunk/gtk/gtkliststore.h
==============================================================================
--- trunk/gtk/gtkliststore.h	(original)
+++ trunk/gtk/gtkliststore.h	Wed Jun 18 09:12:32 2008
@@ -57,7 +57,7 @@
   gint length;
   GtkTreeIterCompareFunc default_sort_func;
   gpointer default_sort_data;
-  GtkDestroyNotify default_sort_destroy;
+  GDestroyNotify default_sort_destroy;
   guint columns_dirty : 1;
 };
 

Modified: trunk/gtk/gtkmain.c
==============================================================================
--- trunk/gtk/gtkmain.c	(original)
+++ trunk/gtk/gtkmain.c	Wed Jun 18 09:12:32 2008
@@ -127,14 +127,14 @@
   GtkCallbackMarshal marshal;
   GtkFunction function;
   gpointer data;
-  GtkDestroyNotify destroy;
+  GDestroyNotify destroy;
 };
 
 struct _GtkClosure
 {
   GtkCallbackMarshal marshal;
   gpointer data;
-  GtkDestroyNotify destroy;
+  GDestroyNotify destroy;
 };
 
 struct _GtkKeySnooperData
@@ -1867,7 +1867,7 @@
 		   GtkFunction		function,
 		   GtkCallbackMarshal	marshal,
 		   gpointer		data,
-		   GtkDestroyNotify	destroy)
+		   GDestroyNotify	destroy)
 {
   static guint quit_id = 1;
   GtkQuitFunction *quitf;
@@ -1985,7 +1985,7 @@
 		      GtkFunction	 function,
 		      GtkCallbackMarshal marshal,
 		      gpointer		 data,
-		      GtkDestroyNotify	 destroy)
+		      GDestroyNotify	 destroy)
 {
   if (marshal)
     {
@@ -2024,7 +2024,7 @@
 		   GtkFunction		function,
 		   GtkCallbackMarshal	marshal,
 		   gpointer		data,
-		   GtkDestroyNotify	destroy)
+		   GDestroyNotify	destroy)
 {
   if (marshal)
     {
@@ -2078,7 +2078,7 @@
 		    GdkInputFunction	function,
 		    GtkCallbackMarshal	marshal,
 		    gpointer		data,
-		    GtkDestroyNotify	destroy)
+		    GDestroyNotify	destroy)
 {
   if (marshal)
     {

Modified: trunk/gtk/gtkmain.h
==============================================================================
--- trunk/gtk/gtkmain.h	(original)
+++ trunk/gtk/gtkmain.h	Wed Jun 18 09:12:32 2008
@@ -167,7 +167,7 @@
 				    GtkFunction	       function,
 				    GtkCallbackMarshal marshal,
 				    gpointer	       data,
-				    GtkDestroyNotify   destroy);
+				    GDestroyNotify     destroy);
 void	   gtk_quit_remove	   (guint	       quit_handler_id);
 void	   gtk_quit_remove_by_data (gpointer	       data);
 #ifndef GTK_DISABLE_DEPRECATED
@@ -178,7 +178,7 @@
 				    GtkFunction	       function,
 				    GtkCallbackMarshal marshal,
 				    gpointer	       data,
-				    GtkDestroyNotify   destroy);
+				    GDestroyNotify     destroy);
 void	   gtk_timeout_remove	   (guint	       timeout_handler_id);
 
 guint	   gtk_idle_add		   (GtkFunction	       function,
@@ -190,7 +190,7 @@
 				    GtkFunction	       function,
 				    GtkCallbackMarshal marshal,
 				    gpointer	       data,
-				    GtkDestroyNotify   destroy);
+				    GDestroyNotify     destroy);
 void	   gtk_idle_remove	   (guint	       idle_handler_id);
 void	   gtk_idle_remove_by_data (gpointer	       data);
 guint	   gtk_input_add_full	   (gint	       source,
@@ -198,7 +198,7 @@
 				    GdkInputFunction   function,
 				    GtkCallbackMarshal marshal,
 				    gpointer	       data,
-				    GtkDestroyNotify   destroy);
+				    GDestroyNotify     destroy);
 void	   gtk_input_remove	   (guint	       input_handler_id);
 #endif /* GTK_DISABLE_DEPRECATED */
 

Modified: trunk/gtk/gtkmenu.c
==============================================================================
--- trunk/gtk/gtkmenu.c	(original)
+++ trunk/gtk/gtkmenu.c	Wed Jun 18 09:12:32 2008
@@ -1033,8 +1033,9 @@
     {
       list = g_list_prepend (list, menu);
     }
-  g_object_set_data_full (G_OBJECT (attach_widget), I_(ATTACHED_MENUS), list, (GtkDestroyNotify) g_list_free);
-  
+  g_object_set_data_full (G_OBJECT (attach_widget), I_(ATTACHED_MENUS), list,
+                          (GDestroyNotify) g_list_free);
+
   if (GTK_WIDGET_STATE (menu) != GTK_STATE_NORMAL)
     gtk_widget_set_state (GTK_WIDGET (menu), GTK_STATE_NORMAL);
   
@@ -1086,7 +1087,8 @@
   list = g_object_steal_data (G_OBJECT (data->attach_widget), ATTACHED_MENUS);
   list = g_list_remove (list, menu);
   if (list)
-    g_object_set_data_full (G_OBJECT (data->attach_widget), I_(ATTACHED_MENUS), list, (GtkDestroyNotify) g_list_free);
+    g_object_set_data_full (G_OBJECT (data->attach_widget), I_(ATTACHED_MENUS), list,
+                            (GDestroyNotify) g_list_free);
   else
     g_object_set_data (G_OBJECT (data->attach_widget), I_(ATTACHED_MENUS), NULL);
   

Modified: trunk/gtk/gtkstock.c
==============================================================================
--- trunk/gtk/gtkstock.h	(original)
+++ trunk/gtk/gtkstock.h	Wed Jun 18 09:12:32 2008
@@ -66,7 +66,7 @@
 void          gtk_stock_set_translate_func (const gchar      *domain,
 					    GtkTranslateFunc  func,
 					    gpointer          data,
-					    GtkDestroyNotify  notify);
+					    GDestroyNotify    notify);
 
 /* Stock IDs (not all are stock items; some are images only) */
 #define GTK_STOCK_DIALOG_AUTHENTICATION \

Modified: trunk/gtk/gtktreedatalist.c
==============================================================================
--- trunk/gtk/gtktreedatalist.c	(original)
+++ trunk/gtk/gtktreedatalist.c	Wed Jun 18 09:12:32 2008
@@ -483,7 +483,7 @@
 
       if (header->destroy)
 	{
-	  GtkDestroyNotify d = header->destroy;
+	  GDestroyNotify d = header->destroy;
 
 	  header->destroy = NULL;
 	  d (header->data);
@@ -515,7 +515,7 @@
 				gint                    sort_column_id,
 				GtkTreeIterCompareFunc  func,
 				gpointer                data,
-				GtkDestroyNotify        destroy)
+				GDestroyNotify          destroy)
 {
   GList *list = header_list;
   GtkTreeDataSortHeader *header = NULL;
@@ -543,7 +543,7 @@
 
   if (header->destroy)
     {
-      GtkDestroyNotify d = header->destroy;
+      GDestroyNotify d = header->destroy;
       
       header->destroy = NULL;
       d (header->data);

Modified: trunk/gtk/gtktreedatalist.h
==============================================================================
--- trunk/gtk/gtktreedatalist.h	(original)
+++ trunk/gtk/gtktreedatalist.h	Wed Jun 18 09:12:32 2008
@@ -47,7 +47,7 @@
   gint sort_column_id;
   GtkTreeIterCompareFunc func;
   gpointer data;
-  GtkDestroyNotify destroy;
+  GDestroyNotify destroy;
 } GtkTreeDataSortHeader;
 
 GtkTreeDataList *_gtk_tree_data_list_alloc          (void);
@@ -77,6 +77,6 @@
 							gint                    sort_column_id,
 							GtkTreeIterCompareFunc  func,
 							gpointer                data,
-							GtkDestroyNotify        destroy);
+							GDestroyNotify          destroy);
 
 #endif /* __GTK_TREE_DATA_LIST_H__ */

Modified: trunk/gtk/gtktreemodelfilter.c
==============================================================================
--- trunk/gtk/gtktreemodelfilter.c	(original)
+++ trunk/gtk/gtktreemodelfilter.c	Wed Jun 18 09:12:32 2008
@@ -91,13 +91,13 @@
 
   GtkTreeModelFilterVisibleFunc visible_func;
   gpointer visible_data;
-  GtkDestroyNotify visible_destroy;
+  GDestroyNotify visible_destroy;
 
   gint modify_n_columns;
   GType *modify_types;
   GtkTreeModelFilterModifyFunc modify_func;
   gpointer modify_data;
-  GtkDestroyNotify modify_destroy;
+  GDestroyNotify modify_destroy;
 
   gint visible_column;
 
@@ -2890,7 +2890,7 @@
 gtk_tree_model_filter_set_visible_func (GtkTreeModelFilter            *filter,
                                         GtkTreeModelFilterVisibleFunc  func,
                                         gpointer                       data,
-                                        GtkDestroyNotify               destroy)
+                                        GDestroyNotify                 destroy)
 {
   g_return_if_fail (GTK_IS_TREE_MODEL_FILTER (filter));
   g_return_if_fail (func != NULL);
@@ -2898,7 +2898,7 @@
 
   if (filter->priv->visible_func)
     {
-      GtkDestroyNotify d = filter->priv->visible_destroy;
+      GDestroyNotify d = filter->priv->visible_destroy;
 
       filter->priv->visible_destroy = NULL;
       d (filter->priv->visible_data);
@@ -2936,7 +2936,7 @@
                                        GType                        *types,
                                        GtkTreeModelFilterModifyFunc  func,
                                        gpointer                      data,
-                                       GtkDestroyNotify              destroy)
+                                       GDestroyNotify                destroy)
 {
   g_return_if_fail (GTK_IS_TREE_MODEL_FILTER (filter));
   g_return_if_fail (func != NULL);
@@ -2944,7 +2944,7 @@
 
   if (filter->priv->modify_destroy)
     {
-      GtkDestroyNotify d = filter->priv->modify_destroy;
+      GDestroyNotify d = filter->priv->modify_destroy;
 
       filter->priv->modify_destroy = NULL;
       d (filter->priv->modify_data);

Modified: trunk/gtk/gtktreemodelfilter.h
==============================================================================
--- trunk/gtk/gtktreemodelfilter.h	(original)
+++ trunk/gtk/gtktreemodelfilter.h	Wed Jun 18 09:12:32 2008
@@ -75,13 +75,13 @@
 void          gtk_tree_model_filter_set_visible_func           (GtkTreeModelFilter           *filter,
                                                                 GtkTreeModelFilterVisibleFunc func,
                                                                 gpointer                      data,
-                                                                GtkDestroyNotify              destroy);
+                                                                GDestroyNotify                destroy);
 void          gtk_tree_model_filter_set_modify_func            (GtkTreeModelFilter           *filter,
                                                                 gint                          n_columns,
                                                                 GType                        *types,
                                                                 GtkTreeModelFilterModifyFunc  func,
                                                                 gpointer                      data,
-                                                                GtkDestroyNotify              destroy);
+                                                                GDestroyNotify                destroy);
 void          gtk_tree_model_filter_set_visible_column         (GtkTreeModelFilter           *filter,
                                                                 gint                          column);
 

Modified: trunk/gtk/gtktreemodelsort.c
==============================================================================
--- trunk/gtk/gtktreemodelsort.c	(original)
+++ trunk/gtk/gtktreemodelsort.c	Wed Jun 18 09:12:32 2008
@@ -201,11 +201,11 @@
 							       gint                    sort_column_id,
 							       GtkTreeIterCompareFunc  func,
 							       gpointer                data,
-							       GtkDestroyNotify        destroy);
+							       GDestroyNotify          destroy);
 static void         gtk_tree_model_sort_set_default_sort_func (GtkTreeSortable        *sortable,
 							       GtkTreeIterCompareFunc  func,
 							       gpointer                data,
-							       GtkDestroyNotify        destroy);
+							       GDestroyNotify          destroy);
 static gboolean     gtk_tree_model_sort_has_default_sort_func (GtkTreeSortable     *sortable);
 
 /* Private functions (sort funcs, level handling and other utils) */
@@ -1356,7 +1356,7 @@
 				   gint                    sort_column_id,
 				   GtkTreeIterCompareFunc  func,
 				   gpointer                data,
-				   GtkDestroyNotify        destroy)
+				   GDestroyNotify          destroy)
 {
   GtkTreeModelSort *tree_model_sort = (GtkTreeModelSort *) sortable;
 
@@ -1372,13 +1372,13 @@
 gtk_tree_model_sort_set_default_sort_func (GtkTreeSortable        *sortable,
 					   GtkTreeIterCompareFunc  func,
 					   gpointer                data,
-					   GtkDestroyNotify        destroy)
+					   GDestroyNotify          destroy)
 {
   GtkTreeModelSort *tree_model_sort = (GtkTreeModelSort *)sortable;
 
   if (tree_model_sort->default_sort_destroy)
     {
-      GtkDestroyNotify d = tree_model_sort->default_sort_destroy;
+      GDestroyNotify d = tree_model_sort->default_sort_destroy;
 
       tree_model_sort->default_sort_destroy = NULL;
       d (tree_model_sort->default_sort_data);
@@ -2398,7 +2398,7 @@
 
   if (tree_model_sort->default_sort_destroy)
     {
-      GtkDestroyNotify d = tree_model_sort->default_sort_destroy;
+      GDestroyNotify d = tree_model_sort->default_sort_destroy;
 
       tree_model_sort->default_sort_destroy = NULL;
       d (tree_model_sort->default_sort_data);

Modified: trunk/gtk/gtktreemodelsort.h
==============================================================================
--- trunk/gtk/gtktreemodelsort.h	(original)
+++ trunk/gtk/gtktreemodelsort.h	Wed Jun 18 09:12:32 2008
@@ -58,7 +58,7 @@
   /* default sort */
   GtkTreeIterCompareFunc default_sort_func;
   gpointer default_sort_data;
-  GtkDestroyNotify default_sort_destroy;
+  GDestroyNotify default_sort_destroy;
 
   /* signal ids */
   guint changed_id;

Modified: trunk/gtk/gtktreeprivate.h
==============================================================================
--- trunk/gtk/gtktreeprivate.h	(original)
+++ trunk/gtk/gtktreeprivate.h	Wed Jun 18 09:12:32 2008
@@ -159,14 +159,14 @@
 
   GtkTreeViewColumnDropFunc column_drop_func;
   gpointer column_drop_func_data;
-  GtkDestroyNotify column_drop_func_data_destroy;
+  GDestroyNotify column_drop_func_data_destroy;
   GList *column_drag_info;
   GtkTreeViewColumnReorder *cur_reorder;
 
   /* ATK Hack */
   GtkTreeDestroyCountFunc destroy_count_func;
   gpointer destroy_count_data;
-  GtkDestroyNotify destroy_count_destroy;
+  GDestroyNotify destroy_count_destroy;
 
   /* Scroll timeout (e.g. during dnd) */
   guint scroll_timeout;
@@ -245,7 +245,7 @@
   GtkTreeViewSearchPositionFunc search_position_func;
   GtkTreeViewSearchEqualFunc search_equal_func;
   gpointer search_user_data;
-  GtkDestroyNotify search_destroy;
+  GDestroyNotify search_destroy;
   gpointer search_position_user_data;
   GDestroyNotify search_position_destroy;
   GtkWidget *search_window;
@@ -257,7 +257,7 @@
 
   GtkTreeViewRowSeparatorFunc row_separator_func;
   gpointer row_separator_data;
-  GtkDestroyNotify row_separator_destroy;
+  GDestroyNotify row_separator_destroy;
 
   gint level_indentation;
 

Modified: trunk/gtk/gtktreeselection.c
==============================================================================
--- trunk/gtk/gtktreeselection.c	(original)
+++ trunk/gtk/gtktreeselection.c	Wed Jun 18 09:12:32 2008
@@ -77,7 +77,7 @@
 
   if (selection->destroy)
     {
-      GtkDestroyNotify d = selection->destroy;
+      GDestroyNotify d = selection->destroy;
 
       selection->destroy = NULL;
       d (selection->user_data);
@@ -256,14 +256,14 @@
 gtk_tree_selection_set_select_function (GtkTreeSelection     *selection,
 					GtkTreeSelectionFunc  func,
 					gpointer              data,
-					GtkDestroyNotify      destroy)
+					GDestroyNotify        destroy)
 {
   g_return_if_fail (GTK_IS_TREE_SELECTION (selection));
   g_return_if_fail (func != NULL);
 
   if (selection->destroy)
     {
-      GtkDestroyNotify d = selection->destroy;
+      GDestroyNotify d = selection->destroy;
 
       selection->destroy = NULL;
       d (selection->user_data);

Modified: trunk/gtk/gtktreeselection.h
==============================================================================
--- trunk/gtk/gtktreeselection.h	(original)
+++ trunk/gtk/gtktreeselection.h	Wed Jun 18 09:12:32 2008
@@ -58,7 +58,7 @@
   GtkSelectionMode type;
   GtkTreeSelectionFunc user_func;
   gpointer user_data;
-  GtkDestroyNotify destroy;
+  GDestroyNotify destroy;
 };
 
 struct _GtkTreeSelectionClass
@@ -83,7 +83,7 @@
 void             gtk_tree_selection_set_select_function (GtkTreeSelection            *selection,
 							 GtkTreeSelectionFunc         func,
 							 gpointer                     data,
-							 GtkDestroyNotify             destroy);
+							 GDestroyNotify               destroy);
 gpointer         gtk_tree_selection_get_user_data       (GtkTreeSelection            *selection);
 GtkTreeView*     gtk_tree_selection_get_tree_view       (GtkTreeSelection            *selection);
 

Modified: trunk/gtk/gtktreesortable.c
==============================================================================
--- trunk/gtk/gtktreesortable.c	(original)
+++ trunk/gtk/gtktreesortable.c	Wed Jun 18 09:12:32 2008
@@ -165,7 +165,7 @@
 				 gint                    sort_column_id,
 				 GtkTreeIterCompareFunc  sort_func,
 				 gpointer                user_data,
-				 GtkDestroyNotify        destroy)
+				 GDestroyNotify          destroy)
 {
   GtkTreeSortableIface *iface;
 
@@ -202,7 +202,7 @@
 gtk_tree_sortable_set_default_sort_func (GtkTreeSortable        *sortable,
 					 GtkTreeIterCompareFunc  sort_func,
 					 gpointer                user_data,
-					 GtkDestroyNotify        destroy)
+					 GDestroyNotify          destroy)
 {
   GtkTreeSortableIface *iface;
 

Modified: trunk/gtk/gtktreesortable.h
==============================================================================
--- trunk/gtk/gtktreesortable.h	(original)
+++ trunk/gtk/gtktreesortable.h	Wed Jun 18 09:12:32 2008
@@ -68,11 +68,11 @@
 				      gint                    sort_column_id,
 				      GtkTreeIterCompareFunc  func,
 				      gpointer                data,
-				      GtkDestroyNotify        destroy);
+				      GDestroyNotify          destroy);
   void     (* set_default_sort_func) (GtkTreeSortable        *sortable,
 				      GtkTreeIterCompareFunc  func,
 				      gpointer                data,
-				      GtkDestroyNotify        destroy);
+				      GDestroyNotify          destroy);
   gboolean (* has_default_sort_func) (GtkTreeSortable        *sortable);
 };
 
@@ -90,14 +90,13 @@
 						  gint                    sort_column_id,
 						  GtkTreeIterCompareFunc  sort_func,
 						  gpointer                user_data,
-						  GtkDestroyNotify        destroy);
+						  GDestroyNotify          destroy);
 void     gtk_tree_sortable_set_default_sort_func (GtkTreeSortable        *sortable,
 						  GtkTreeIterCompareFunc  sort_func,
 						  gpointer                user_data,
-						  GtkDestroyNotify        destroy);
+						  GDestroyNotify          destroy);
 gboolean gtk_tree_sortable_has_default_sort_func (GtkTreeSortable        *sortable);
-						  
-						  
+
 G_END_DECLS
 
 #endif /* __GTK_TREE_SORTABLE_H__ */

Modified: trunk/gtk/gtktreestore.c
==============================================================================
--- trunk/gtk/gtktreestore.c	(original)
+++ trunk/gtk/gtktreestore.c	Wed Jun 18 09:12:32 2008
@@ -110,11 +110,11 @@
 							gint                    sort_column_id,
 							GtkTreeIterCompareFunc  func,
 							gpointer                data,
-							GtkDestroyNotify        destroy);
+							GDestroyNotify          destroy);
 static void     gtk_tree_store_set_default_sort_func   (GtkTreeSortable        *sortable,
 							GtkTreeIterCompareFunc  func,
 							gpointer                data,
-							GtkDestroyNotify        destroy);
+							GDestroyNotify          destroy);
 static gboolean gtk_tree_store_has_default_sort_func   (GtkTreeSortable        *sortable);
 
 
@@ -431,7 +431,7 @@
 
   if (tree_store->default_sort_destroy)
     {
-      GtkDestroyNotify d = tree_store->default_sort_destroy;
+      GDestroyNotify d = tree_store->default_sort_destroy;
 
       tree_store->default_sort_destroy = NULL;
       d (tree_store->default_sort_data);
@@ -3139,7 +3139,7 @@
 			      gint                    sort_column_id,
 			      GtkTreeIterCompareFunc  func,
 			      gpointer                data,
-			      GtkDestroyNotify        destroy)
+			      GDestroyNotify          destroy)
 {
   GtkTreeStore *tree_store = (GtkTreeStore *) sortable;
 
@@ -3155,13 +3155,13 @@
 gtk_tree_store_set_default_sort_func (GtkTreeSortable        *sortable,
 				      GtkTreeIterCompareFunc  func,
 				      gpointer                data,
-				      GtkDestroyNotify        destroy)
+				      GDestroyNotify          destroy)
 {
   GtkTreeStore *tree_store = (GtkTreeStore *) sortable;
 
   if (tree_store->default_sort_destroy)
     {
-      GtkDestroyNotify d = tree_store->default_sort_destroy;
+      GDestroyNotify d = tree_store->default_sort_destroy;
 
       tree_store->default_sort_destroy = NULL;
       d (tree_store->default_sort_data);

Modified: trunk/gtk/gtktreestore.h
==============================================================================
--- trunk/gtk/gtktreestore.h	(original)
+++ trunk/gtk/gtktreestore.h	Wed Jun 18 09:12:32 2008
@@ -56,7 +56,7 @@
   GType *column_headers;
   GtkTreeIterCompareFunc default_sort_func;
   gpointer default_sort_data;
-  GtkDestroyNotify default_sort_destroy;
+  GDestroyNotify default_sort_destroy;
   guint columns_dirty : 1;
 };
 

Modified: trunk/gtk/gtktreeview.c
==============================================================================
--- trunk/gtk/gtktreeview.c	(original)
+++ trunk/gtk/gtktreeview.c	Wed Jun 18 09:12:32 2008
@@ -11496,7 +11496,7 @@
 gtk_tree_view_set_column_drag_function (GtkTreeView               *tree_view,
 					GtkTreeViewColumnDropFunc  func,
 					gpointer                   user_data,
-					GtkDestroyNotify           destroy)
+					GDestroyNotify             destroy)
 {
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 
@@ -13779,7 +13779,7 @@
 gtk_tree_view_set_destroy_count_func (GtkTreeView             *tree_view,
 				      GtkTreeDestroyCountFunc  func,
 				      gpointer                 data,
-				      GtkDestroyNotify         destroy)
+				      GDestroyNotify           destroy)
 {
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 
@@ -13917,7 +13917,7 @@
 gtk_tree_view_set_search_equal_func (GtkTreeView                *tree_view,
 				     GtkTreeViewSearchEqualFunc  search_equal_func,
 				     gpointer                    search_user_data,
-				     GtkDestroyNotify            search_destroy)
+				     GDestroyNotify              search_destroy)
 {
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
   g_return_if_fail (search_equal_func != NULL);
@@ -14982,10 +14982,10 @@
  * Since: 2.6
  **/
 void
-gtk_tree_view_set_row_separator_func (GtkTreeView                *tree_view,
-				      GtkTreeViewRowSeparatorFunc func,
-				      gpointer                    data,
-				      GtkDestroyNotify            destroy)
+gtk_tree_view_set_row_separator_func (GtkTreeView                 *tree_view,
+				      GtkTreeViewRowSeparatorFunc  func,
+				      gpointer                     data,
+				      GDestroyNotify               destroy)
 {
   g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 

Modified: trunk/gtk/gtktreeview.h
==============================================================================
--- trunk/gtk/gtktreeview.h	(original)
+++ trunk/gtk/gtktreeview.h	Wed Jun 18 09:12:32 2008
@@ -197,7 +197,7 @@
 void                   gtk_tree_view_set_column_drag_function      (GtkTreeView               *tree_view,
 								    GtkTreeViewColumnDropFunc  func,
 								    gpointer                   user_data,
-								    GtkDestroyNotify           destroy);
+								    GDestroyNotify             destroy);
 
 /* Actions */
 void                   gtk_tree_view_scroll_to_point               (GtkTreeView               *tree_view,
@@ -319,7 +319,7 @@
 void                       gtk_tree_view_set_search_equal_func (GtkTreeView                *tree_view,
 								GtkTreeViewSearchEqualFunc  search_equal_func,
 								gpointer                    search_user_data,
-								GtkDestroyNotify            search_destroy);
+								GDestroyNotify              search_destroy);
 
 GtkEntry                     *gtk_tree_view_get_search_entry         (GtkTreeView                   *tree_view);
 void                          gtk_tree_view_set_search_entry         (GtkTreeView                   *tree_view,
@@ -371,7 +371,7 @@
 void gtk_tree_view_set_destroy_count_func (GtkTreeView             *tree_view,
 					   GtkTreeDestroyCountFunc  func,
 					   gpointer                 data,
-					   GtkDestroyNotify         destroy);
+					   GDestroyNotify           destroy);
 
 void     gtk_tree_view_set_fixed_height_mode (GtkTreeView          *tree_view,
 					      gboolean              enable);
@@ -392,7 +392,7 @@
 void                        gtk_tree_view_set_row_separator_func (GtkTreeView                *tree_view,
 								  GtkTreeViewRowSeparatorFunc func,
 								  gpointer                    data,
-								  GtkDestroyNotify            destroy);
+								  GDestroyNotify              destroy);
 
 GtkTreeViewGridLines        gtk_tree_view_get_grid_lines         (GtkTreeView                *tree_view);
 void                        gtk_tree_view_set_grid_lines         (GtkTreeView                *tree_view,

Modified: trunk/gtk/gtktreeviewcolumn.c
==============================================================================
--- trunk/gtk/gtktreeviewcolumn.c	(original)
+++ trunk/gtk/gtktreeviewcolumn.c	Wed Jun 18 09:12:32 2008
@@ -67,7 +67,7 @@
   GSList *attributes;
   GtkTreeCellDataFunc func;
   gpointer func_data;
-  GtkDestroyNotify destroy;
+  GDestroyNotify destroy;
   gint requested_width;
   gint real_width;
   guint expand : 1;
@@ -391,7 +391,7 @@
 
       if (info->destroy)
 	{
-	  GtkDestroyNotify d = info->destroy;
+	  GDestroyNotify d = info->destroy;
 
 	  info->destroy = NULL;
 	  d (info->func_data);
@@ -1663,7 +1663,7 @@
 					 GtkCellRenderer     *cell_renderer,
 					 GtkTreeCellDataFunc  func,
 					 gpointer             func_data,
-					 GtkDestroyNotify     destroy)
+					 GDestroyNotify       destroy)
 {
   gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (tree_column),
                                       cell_renderer,

Modified: trunk/gtk/gtktreeviewcolumn.h
==============================================================================
--- trunk/gtk/gtktreeviewcolumn.h	(original)
+++ trunk/gtk/gtktreeviewcolumn.h	Wed Jun 18 09:12:32 2008
@@ -148,7 +148,7 @@
 								  GtkCellRenderer         *cell_renderer,
 								  GtkTreeCellDataFunc      func,
 								  gpointer                 func_data,
-								  GtkDestroyNotify         destroy);
+								  GDestroyNotify           destroy);
 void                    gtk_tree_view_column_clear_attributes    (GtkTreeViewColumn       *tree_column,
 								  GtkCellRenderer         *cell_renderer);
 void                    gtk_tree_view_column_set_spacing         (GtkTreeViewColumn       *tree_column,

Modified: trunk/gtk/gtktypeutils.h
==============================================================================
--- trunk/gtk/gtktypeutils.h	(original)
+++ trunk/gtk/gtktypeutils.h	Wed Jun 18 09:12:32 2008
@@ -115,7 +115,6 @@
 typedef struct _GtkArg	       	     GtkArg;
 typedef struct _GtkObject   	     GtkObject; /* object forward declaration */
 typedef gboolean (*GtkFunction)	    (gpointer      data);
-typedef void (*GtkDestroyNotify)    (gpointer      data);
 typedef void (*GtkCallbackMarshal)  (GtkObject    *object,
 				     gpointer      data,
 				     guint         n_args,
@@ -123,6 +122,7 @@
 
 #ifndef GTK_DISABLE_DEPRECATED
 
+typedef void (*GtkDestroyNotify)    (gpointer      data);
 typedef void (*GtkSignalFunc)       (void);
 
 #endif /* GTK_DISABLE_DEPRECATED */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/gtk/gtkactiongroup.c	(original)
+++ trunk/gtk/gtkactiongroup.c	Wed Jun 18 09:12:32 2008
@@ -56,7 +56,7 @@
 
   GtkTranslateFunc translate_func;
   gpointer         translate_data;
-  GtkDestroyNotify translate_notify;   
+  GDestroyNotify   translate_notify;
 };
 
 enum 
@@ -1247,9 +1247,9 @@
  * @action_group: a #GtkActionGroup
  * @func: a #GtkTranslateFunc
  * @data: data to be passed to @func and @notify
  * @notify: a #GtkDestroyNotify function to be called when @action_group is 
  *   destroyed and when the translation function is changed again
- * 
+ *
  * Sets a function to be used for translating the @label and @tooltip of 
  * #GtkActionGroupEntry<!-- -->s added by gtk_action_group_add_actions().
  *
@@ -1262,7 +1262,7 @@
 gtk_action_group_set_translate_func (GtkActionGroup   *action_group,
 				     GtkTranslateFunc  func,
 				     gpointer          data,
-				     GtkDestroyNotify  notify)
+				     GDestroyNotify    notify)
 {
   g_return_if_fail (GTK_IS_ACTION_GROUP (action_group));
   
@@ -1247,9 +1247,9 @@
  * @func: a #GtkTranslateFunc
  * @data: data to be passed to @func and @notify
- * @notify: a #GtkDestroyNotify function to be called when @action_group is 
+ * @notify: a #GDestroyNotify function to be called when @action_group is
  *   destroyed and when the translation function is changed again

Modified: trunk/gtk/gtkactiongroup.h
==============================================================================
--- trunk/gtk/gtkstock.c	(original)
+++ trunk/gtk/gtkstock.c	Wed Jun 18 09:12:32 2008
@@ -47,7 +47,7 @@
 {
   GtkTranslateFunc func;
   gpointer data;
-  GtkDestroyNotify notify;
+  GDestroyNotify notify;
 };
 
 static void
@@ -410,7 +410,7 @@
  * @domain: the translation domain for which @func shall be used
  * @func: a #GtkTranslateFunc 
  * @data: data to pass to @func
  * @notify: a #GtkDestroyNotify that is called when @data is 
  *   no longer needed
  *
  * Sets a function to be used for translating the @label of 
@@ -426,7 +426,7 @@
 gtk_stock_set_translate_func (const gchar      *domain,
 			      GtkTranslateFunc  func,
 			      gpointer          data,
-			      GtkDestroyNotify  notify)
+			      GDestroyNotify    notify)
 {
   GtkStockTranslateFunc *translate;
   gchar *domainname;
@@ -410,7 +410,7 @@
  * @func: a #GtkTranslateFunc 
  * @data: data to pass to @func
- * @notify: a #GtkDestroyNotify that is called when @data is 
+ * @notify: a #GDestroyNotify that is called when @data is
  *   no longer needed
  *

Modified: trunk/gtk/gtkstock.h
==============================================================================